[![banner](https://raw.githubusercontent.com/nevermined-io/assets/main/images/logo/banner_logo.png)](https://nevermined.io)

# Python SDK to interact with the Nevermined Payments Protocol

> Python SDK to interact with the Nevermined Payments Protocol
> [nevermined.io](https://nevermined.io)

## Quickstart

pip install nevermined/payments-py

### Initialize the payments library

```

Payments(session_key=session_key, environment=Environment.appStaging, app_id="your_app_id", version="1.0.0", session_key=your_session_key, marketplace_auth_token=your_marketplace_auth_token)

```

